package Bencher::ScenarioR::LogGer::InitTarget;

our $VERSION = 0.013; # VERSION

our $results = [
  [
    200,
    "OK",
    [
      {
        errors => 0.0015,
        participant => "with LGO:Composite (Screen+File & pattern layouts)",
        rate => 2.8,
        samples => 7,
        time => 360,
        vs_slowest => 1,
      },
      {
        errors => 0.0005,
        participant => "default",
        rate => 2.8,
        samples => 7,
        time => 350,
        vs_slowest => 1,
      },
      {
        errors => 0.00032,
        participant => "with LGO:Composite (Screen+File)",
        rate => 2.92,
        samples => 7,
        time => 343,
        vs_slowest => 1.05,
      },
      {
        errors => 0.00042,
        participant => "with LGO:Composite (Screen)",
        rate => 4,
        samples => 7,
        time => 250,
        vs_slowest => 1.4,
      },
      {
        errors => 0.00016,
        participant => "with LGO:File",
        rate => 5.32,
        samples => 7,
        time => 188,
        vs_slowest => 1.92,
      },
      {
        errors => 0.0003,
        participant => "with LGO:Screen",
        rate => 7.4,
        samples => 7,
        time => 130,
        vs_slowest => 2.7,
      },
      {
        errors => 0.00015,
        participant => "with LGO:Composite (0 outputs)",
        rate => 7.4,
        samples => 7,
        time => 130,
        vs_slowest => 2.7,
      },
    ],
    {
      "func.bencher_args"              => {
                                            action => "bench",
                                            note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                            scenario_module => "LogGer::InitTarget",
                                          },
      "func.bencher_version"           => undef,
      "func.code_startup"              => undef,
      "func.cpu_info"                  => [
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "epb",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 0,
                                              speed                        => 3222.607,
                                              stepping                     => 7,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "epb",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 1,
                                              speed                        => 3303.399,
                                              stepping                     => 7,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "epb",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 2,
                                              speed                        => 3264.801,
                                              stepping                     => 7,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "epb",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 3,
                                              speed                        => 3289.019,
                                              stepping                     => 7,
                                            },
                                          ],
      "func.elapsed_time"              => 15.5287089347839,
      "func.module_startup"            => undef,
      "func.module_versions"           => {
                                            "__PACKAGE__" => 1.041,
                                            "Bencher::Scenario::LogGer::InitTarget" => undef,
                                            "Benchmark::Dumb" => 0.111,
                                            "Devel::Platform::Info" => 0.16,
                                            "perl" => "v5.26.0",
                                            "Sys::Info" => 0.78,
                                          },
      "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 6]],
      "func.platform_info"             => {
                                            archname => "x86_64",
                                            codename => "sonya",
                                            is32bit  => 0,
                                            is64bit  => 1,
                                            kernel   => "linux-4.8.0-53-generic",
                                            kname    => "Linux",
                                            kvers    => "4.8.0-53-generic",
                                            osflag   => "linux",
                                            oslabel  => "LinuxMint",
                                            osname   => "GNU/Linux",
                                            osvers   => 18.2,
                                            source   => {
                                                          "cat /etc/.issue" => "",
                                                          "cat /etc/issue"  => "Linux Mint 18.2 Sonya \\n \\l",
                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 18.2 Sonya\nRelease:\t18.2\nCodename:\tsonya",
                                                          "uname -a"        => "Linux builder 4.8.0-53-generic #56~16.04.1-Ubuntu SMP Tue May 16 01:18:56 UTC 2017 x86_64 x86_64 x86_64 GNU/Linux",
                                                          "uname -m"        => "x86_64",
                                                          "uname -o"        => "GNU/Linux",
                                                          "uname -r"        => "4.8.0-53-generic",
                                                          "uname -s"        => "Linux",
                                                        },
                                          },
      "func.precision"                 => 7,
      "func.scenario_module"           => "Bencher::Scenario::LogGer::InitTarget",
      "func.scenario_module_md5sum"    => "031be9742810dd7b169251894d4ad410",
      "func.scenario_module_mtime"     => 1499942633,
      "func.scenario_module_sha1sum"   => "04369046d22a6d1e2ce7ae2fc07be5e54ddf2e04",
      "func.scenario_module_sha256sum" => "733fb6fa020e5d8133f3addf99e97085c8878254367f5d714a603650c8820b2f",
      "func.time_end"                  => 1545303580.45636,
      "func.time_factor"               => 1000,
      "func.time_start"                => 1545303564.92765,
      "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
      "table.field_units"              => [undef, undef, "/s", "ms"],
      "table.fields"                   => [
                                            "participant",
                                            "dataset",
                                            "rate",
                                            "time",
                                            "vs_slowest",
                                            "errors",
                                            "samples",
                                          ],
    },
  ],
];

1;
# ABSTRACT: Benchmark init_target()

=head1 DESCRIPTION

This module is automatically generated by Pod::Weaver::Plugin::Bencher::Scenario during distribution build.

A Bencher::ScenarioR::* module contains the raw result of sample benchmark and might be useful for some stuffs later.

